@@ -2,10 +2,12 @@
 import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
 
-import { NativeModules } from 'react-native';
-module.exports = NativeModules.DemoModuleExample;
+import {NativeModules} from 'react-native';
+module.exports = NativeModules.ToastExample;
+
+import ToastExample from './ToastExample';
+
 
-var DemoModule = require('NativeModules').DemoModuleExample;
 
 var DemoLibrary = {
   checkEmail: function (email) {
@@ -29,7 +31,7 @@ var DemoLibrary = {
 
       }).then(response => response.text())
         .then((response) => {
-          console.log('local version ' , DemoModule.getPackageName())
+          ToastExample.show('Awesome', ToastExample.SHORT);
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
           console.log('version ', version)
